# Topsis Calci

Topsis Calci is a Python package implementing Topsis method for decision analysis.

## Installation
```
pip install topsis-calci
```

## Usage
```
topsis input_file weights impacts output_file
```

**OR**

```
python topsis.py input_file weights impacts output_file
```

#### Inputs:-
* input_file -> "Excel/Csv" file path
* weights -> Comma seperated integers
* impacts -> Comma seperated +/- impacts
* output_file -> output csv file path"

#### Outputs:-
* Creates a csv file on "output_file" path containing score and Ranks

#### Examples :-
Refer [Examples](./examples)

## License
This Project is Licensed under [**BSD-4-Clause**](./LICENSE.txt)
